@@ -233,8 +233,10 @@ void print_rss_hkey(u8 *hkey, u32 hkey_size)
 	u32 i;
 
 	printf("RSS hash key:\n");
-	if (!hkey_size || !hkey)
+	if (!hkey_size || !hkey) {
 		printf("Operation not supported\n");
+		return;
+	}
 
 	for (i = 0; i < hkey_size; i++) {
 		if (i == (hkey_size - 1))
