@@ -58,7 +58,9 @@ void dump_json_rss_info(struct cmd_context *ctx, u32 *indir_table,
 	open_json_object("rss-input-transformation");
 	print_bool(PRINT_JSON, "symmetric-xor", NULL,
 		   (input_xfrm & RXH_XFRM_SYM_XOR) ? true : false);
-	if (input_xfrm & ~RXH_XFRM_SYM_XOR)
+	print_bool(PRINT_JSON, "symmetric-or-xor", NULL,
+		   (input_xfrm & RXH_XFRM_SYM_OR_XOR) ? true : false);
+	if (input_xfrm & ~(RXH_XFRM_SYM_XOR | RXH_XFRM_SYM_OR_XOR))
 		print_uint(PRINT_JSON, "raw", NULL, input_xfrm);
 
 	close_json_object();
@@ -177,6 +179,9 @@ int rss_reply_cb(const struct nlmsghdr *nlhdr, void *data)
 		printf("    symmetric-xor: %s\n",
 		       (input_xfrm & RXH_XFRM_SYM_XOR) ? "on" : "off");
 		input_xfrm &= ~RXH_XFRM_SYM_XOR;
+		printf("    symmetric-or-xor: %s\n",
+		       (input_xfrm & RXH_XFRM_SYM_OR_XOR) ? "on" : "off");
+		input_xfrm &= ~RXH_XFRM_SYM_OR_XOR;
 
 		if (input_xfrm)
 			printf("    Unknown bits in RSS input transformation: 0x%x\n", input_xfrm);
