@@ -25,6 +25,7 @@ static struct test_case {
 	{ 1, "" },
 	{ 0, "devname" },
 	{ 0, "15_char_devname" },
+	{ !IS_NL, "--json devname" },
 	/* netlink interface allows names up to 127 characters */
 	{ !IS_NL, "16_char_devname!" },
 	{ !IS_NL, "127_char_devname0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcdef0123456789abcde" },
@@ -287,9 +288,10 @@ static struct test_case {
 	{ 0, "--set-fec devname encoding off" },
 	{ 0, "--set-fec devname encoding baser rs" },
 	{ 0, "--set-fec devname encoding auto auto" },
-	{ 1, "--set-fec devname encoding foo" },
-	{ 1, "--set-fec devname encoding auto foo" },
-	{ 1, "--set-fec devname encoding none" },
+	/* encoding names are validated by kernel with netlink */
+	{ !IS_NL, "--set-fec devname encoding foo" },
+	{ !IS_NL, "--set-fec devname encoding auto foo" },
+	{ !IS_NL, "--set-fec devname encoding none" },
 	{ 1, "--set-fec devname auto" },
 	/* can't test --set-priv-flags yet */
 	{ 0, "-h" },
